@@ -1,5 +1,6 @@
 from functools import update_wrapper
 import inspect, itertools
+import warnings
 
 def format_argspec_plus(fn, grouped=True):
     """Returns a dictionary of formatted, introspected function arguments.
@@ -65,7 +66,7 @@ def unique_symbols(used, *bases):
                 break
         else:
             raise NameError("exhausted namespace for symbol base %s" % base)
-            
+
 def decorator(target):
     """A signature-matching decorator factory."""
 
@@ -102,4 +103,16 @@ def curry(fn, *args, **kwargs):
             tocall.cargs = []
             return fn(*fnargs)
     tocall.cargs = cargs
-    return tocall
\ No newline at end of file
+    return tocall
+
+def deprecate(message):
+    """
+        Decorate a function to emit a deprecation warning with the given
+        message.
+    """
+    @decorator
+    def decorate(fn, *args, **kw):
+        warnings.warn(message, DeprecationWarning, 2)
+        return fn(*args, **kw)
+    return decorate
+
